Class: AmazonAds::GeoLocations

Inherits:
API
  • Object
show all
Defined in:
lib/amazon_ads/apis/geo_locations.rb

Constant Summary

Constants inherited from API

API::ENDPOINTS

Instance Attribute Summary

Attributes inherited from API

#access_token, #account_id, #profile_id, #region, #retries

Instance Method Summary collapse

Methods inherited from API

#endpoint, #http, #initialize

Constructor Details

This class inherits a constructor from AmazonAds::API

Instance Method Details

#create_geo_location(geo_locations:) ⇒ Object

Create geo location targeting definitions. Supports smart locations, which target users based on their percentile rank within a Smart Location Index, and radius locations, which target users within a specified distance of an address or coordinate. Note: radius locations are currently in beta.

Signature:

  • (geo_locations: Array[untyped]) -> HTTP::Response



7
8
9
# File 'lib/amazon_ads/apis/geo_locations.rb', line 7

def create_geo_location(geo_locations:)
  request(:post, "/adsApi/v1/create/geoLocations", json: { "geoLocations" => geo_locations }.compact)
end